==> egg-user-service-2.0.1-20211111.110038-1-sources.jar: com/bxm/egg/user/invite/egg/UserEggInviteService.java <==
package com.bxm.egg.user.invite.egg;

import com.bxm.egg.user.model.dto.invite.RollBarrageDTO;
import com.bxm.egg.user.model.dto.invite.egg.InviteUserListDTO;
import com.bxm.egg.user.model.entity.TempInviteBindEntity;
import com.bxm.egg.user.model.param.invite.InviteBindParam;
import com.bxm.egg.user.model.param.invite.egg.InvitePageParam;
import com.bxm.newidea.component.dto.IPageModel;

import java.util.Date;
import java.util.List;

/**
 * 蛋蛋佳用户邀请service
 *
 * @author wzy
 * @version 1.0
 * @date 2021/9/24 5:11 下午
 */
public interface UserEggInviteService {

    /**
     * 分页获取用户邀请列表
     *
     * @param invitePageParam 入参
     * @return 分页邀请数据
     */
    IPageModel<InviteUserListDTO> inviteList(InvitePageParam invitePageParam);

    /**
     * 获取邀请用户id
     *
     * @param userId 用户id
     * @return 邀请用户id
     */
    Long getInviteUserId(Long userId);

    /**
     * 统计邀请好友的个数
     *
     * @param userId 用户id
     * @return 邀请好友的个数
     */
    int countInviteUser(Long userId);

    /**
     * 获取用户邀请好友的最近五个头像列表
     *
     * @param userId 用户id
     * @return 头像列表
     */
    List<String> getUserInviteHeadImgList(Long userId);

    /**
     * 获取滚动弹幕
     *
     * @return 弹幕列表
     */
    List<RollBarrageDTO> getRollBarrage();

    /**
     * 临时绑定邀请关系
     *
     * @param inviteBindParam 入参
     * @return 是否绑定成功
     */
    Boolean tempBindInvite(InviteBindParam inviteBindParam);

    /**
     * 获取用户临时绑定信息
     *
     * @param unionId 入参
     * @return 绑定信息
     */
    TempInviteBindEntity getUserTempBindInvite(String unionId);


    /**
     * 删除临时邀请关系
     *
     * @param unionId 微信的唯一标识
     */
    void delInviteBindByUnionId(String unionId);

    /**
     * 删除临时邀请关系
     *
     * @param date 删除此时间之前的临时信息
     */
    void delInviteBindByDate(Date date);

    Integer getReceiveContributeFoods(Long userId);

    Boolean receiveFoods(Long userId);
}

==> egg-user-service-2.0.6.2-sources.jar: com/bxm/egg/user/invite/egg/UserEggInviteService.java <==
package com.bxm.egg.user.invite.egg;

import com.bxm.egg.user.model.dto.invite.RollBarrageDTO;
import com.bxm.egg.user.model.dto.invite.egg.InviteUserListDTO;
import com.bxm.egg.user.model.entity.EggInviteEntity;
import com.bxm.egg.user.model.entity.TempInviteBindEntity;
import com.bxm.egg.user.model.param.invite.ApplyFriendParam;
import com.bxm.egg.user.model.param.invite.CheckBindParam;
import com.bxm.egg.user.model.param.invite.InviteBindParam;
import com.bxm.egg.user.model.param.invite.egg.InvitePageParam;
import com.bxm.newidea.component.bo.Message;
import com.bxm.newidea.component.dto.IPageModel;

import java.util.Date;
import java.util.List;

/**
 * 蛋蛋佳用户邀请service
 *
 * @author wzy
 * @version 1.0
 * @date 2021/9/24 5:11 下午
 */
public interface UserEggInviteService {

    /**
     * 分页获取用户邀请列表
     *
     * @param invitePageParam 入参
     * @return 分页邀请数据
     */
    IPageModel<InviteUserListDTO> inviteList(InvitePageParam invitePageParam);

    /**
     * 插入邀请信息
     */
    void insertInviteInfo(EggInviteEntity eggInviteEntity);

    /**
     * 获取邀请用户id
     *
     * @param userId 用户id
     * @return 邀请用户id
     */
    Long getInviteUserId(Long userId);

    /**
     * 统计邀请好友的个数
     *
     * @param userId 用户id
     * @return 邀请好友的个数
     */
    int countInviteUser(Long userId);

    /**
     * 获取用户邀请好友的最近五个头像列表
     *
     * @param userId 用户id
     * @return 头像列表
     */
    List<String> getUserInviteHeadImgList(Long userId);

    /**
     * 获取滚动弹幕
     *
     * @return 弹幕列表
     */
    List<RollBarrageDTO> getRollBarrage();

    /**
     * 临时绑定邀请关系
     *
     * @param inviteBindParam 入参
     * @return 是否绑定成功
     */
    Boolean tempBindInvite(InviteBindParam inviteBindParam);

    /**
     * 获取用户临时绑定信息
     *
     * @param unionId 入参
     * @return 绑定信息
     */
    TempInviteBindEntity getUserTempBindInvite(String unionId);


    /**
     * 删除临时邀请关系
     *
     * @param unionId 微信的唯一标识
     */
    void delInviteBindByUnionId(String unionId);

    /**
     * 删除临时邀请关系
     *
     * @param date 删除此时间之前的临时信息
     */
    void delInviteBindByDate(Date date);

    /**
     * 获取可以领取的粮食
     *
     * @param userId 用户id
     * @return 粮食数
     */
    Integer getReceiveContributeFoods(Long userId);

    /**
     * 领取粮食
     *
     * @param userId 用户id
     * @return 是否成功
     */
    Boolean receiveFoods(Long userId);

    /**
     * 删除邀请关系
     *
     * @param userId 用户id
     */
    void delInviteInfoByUserId(Long userId);

    /**
     * 获取邀请用户id
     *
     * @param beInviteUserId 被邀请用户id
     * @return 邀请用户id
     */
    EggInviteEntity getInviteUserIdByBeUser(Long beInviteUserId);

    /**
     * 通过好友申请
     * @param param
     * @return
     */
    Message adoptFriendApply(ApplyFriendParam param);

    /**
     * 发送好友申请
     * 功能：判断当天是否申请或好友申请； 发送好友申请推送
     * @param param
     * @return
     */
    Message sendFriendApply(CheckBindParam param);

    /**
     * 校验用户之间是否为好友
     * @param param
     * @return
     */
    Boolean checkIsFriend(CheckBindParam param);
}
